import QtQuick 2.4
import "string_format.js" as Format

Item {
    id: root
    property variant c360program: workoutProgram.c360Program
    property int segmentTime: c360program.phaseTimeRemaining
    property int phase: c360program.currentPhase

    signal phaseTitleChanged(string title)

    onPhaseChanged: {
        var text = qsTr(c360Modes.title(phase))
        root.phaseTitleChanged(text)
    }

    ListModel {
        id: c360Modes

        function imagePath(productModel) {
            var model = machineinfo.modelString ? machineinfo.modelString : "XCS900"
            switch(machineinfo.modelString) {
            case "XCS900":
                return "graphics/c360/XCS900/C360_XCS900_"
            case "XCS400":
                return "graphics/c360/XCS400/C360_XCS400_"
            default:
                return "graphics/c360/XCS400/C360_XCS400_"
            }
        }

        function title(index) {
            return [ qsTr("STRIDE FORWARD"),
                    qsTr("STRIDE FORWARD & PUSH ARMS"),
                    qsTr("STAND ON SIDES, LEFT ARM ONLY"),
                    qsTr("STAND ON SIDES, RIGHT ARM ONLY"),
                    qsTr("REVERSE STRIDE & BEND KNEES"),
                    qsTr("STRIDE FORWARD & LIFT HEELS"),
                    qsTr("STRIDE FORWARD & PULL ARMS"),
                    qsTr("HOLD SIDE RAILS, REVERSE STRIDE & LIFT TOES"),
                    qsTr("STAND ON SIDES, CHANGE GRIP, PUSH & PULL ARMS"),
                    qsTr("RECOVER - STRIDE FORWARD")
                    ][index]
        }
        function instructionsList(index) {
            return [
                     [qsTr("Feet on Foot Pedals") ,qsTr("Stride Forward")],
                     [qsTr("Stride Forward") ,qsTr("Push Arms") ],
                     [qsTr("Feet On Side Steps") ,qsTr("Bend Knees") ,qsTr("Right Arm on Handrail") ],
                     [qsTr("Feet On Side Steps") ,qsTr("Bend Knees") ,qsTr("Left Arm on Handrail") ],
                     [qsTr("Feet On Pedals") ,qsTr("Reverse Stride") ,qsTr("Bend Knees") ],
                     [qsTr("Stride Forward") ,qsTr("Lift Heels") ],
                     [qsTr("Feet On Pedals") ,qsTr("Stride Forward") ,qsTr("Pull Arms") ],
                     [qsTr("Reverse Stride") ,qsTr("Bend Knees") ,qsTr("Lift Toes") ],
                     [qsTr("Feet On Side Steps") ,qsTr("Bend Knees") ,qsTr("Try Different Grip") ],
                     [qsTr("Feet on Foot Pedals") ,qsTr("Stride Forward")]
                    ][index];
        }

        function instructions(index) {
            var instr = instructionsList(index)
            return "<ul>" + instr.map(function(s) { return "<li>" + s + "</li>" }).join("") + "</ul>"
        }

        ListElement {
            images: [ ListElement { source: "motion1-1.jpg" },
                      ListElement { source: "motion1-2.jpg" }
            ]
            icon : "C360_1-1_Forward.png"
        }
        ListElement {
            images: [ ListElement { source: "motion2-1.jpg" },
                      ListElement { source: "motion2-2.jpg" }
            ]
            icon : "C360_2-1_Forward_Push_Arms.png"
        }
        ListElement {
            images: [ ListElement { source: "motion3-1.jpg" },
                      ListElement { source: "motion3-2.jpg" }
            ]
            icon : "C360_3-1_Left_Arm.png"
        }
        ListElement {
            images: [ ListElement { source: "motion4-1.jpg" },
                      ListElement { source: "motion4-2.jpg" }
            ]
            icon : "C360_4-1_Right_Arm.png"
        }
        ListElement {
            images: [ ListElement { source: "motion5-1.jpg" },
                      ListElement { source: "motion5-2.jpg" }
            ]
            icon : "C360_5-1_Reverse_Bend_Knees.png"
        }
        ListElement {
            images: [ ListElement { source: "motion6-1.jpg" },
                      ListElement { source: "motion6-2.jpg" }
            ]
            icon : "C360_6-1_Forward_Heels.png"
        }
        ListElement {
            images: [ ListElement { source: "motion7-1.jpg" },
                      ListElement { source: "motion7-2.jpg" }
            ]
            icon : "C360_7-1_Forward_Pull_Arms.png"
        }
        ListElement {
            images: [ ListElement { source: "motion8-1.jpg" },
                      ListElement { source: "motion8-2.jpg" }
            ]
            icon : "C360_8-1_Hold_Side_Rails.png"
        }
        ListElement {
            images: [ ListElement { source: "motion9-1.jpg" },
                      ListElement { source: "motion9-2.jpg" }
            ]
            icon : "C360_9-1_Stand_On_Sides.png"
        }
        ListElement {
            images: [ ListElement { source: "motion10-1.jpg" },
                      ListElement { source: "motion10-2.jpg" }
            ]
            icon : "C360_10-1_Recover.png"
        }
    }

    Component {
        id: phaseImages

        Image {
            id: c360PhaseView
            property int imageIndex: viewObject.imageNum

            onImageIndexChanged: {
                photo.source = (c360Modes.imagePath() + images.get(imageIndex).source)
            }
            anchors.verticalCenter: parent.verticalCenter
            width: parent.width
            height: parent.height

            source: "graphics/224/224_Data_Main_Window_Bkgr.png"

            Image {
                id: header
                source: "graphics/c360/Header.png"

                anchors { top: parent.top; topMargin: 3 ; left: parent.left ; leftMargin: 2; right: parent.right; rightMargin: 3 }
                width: 1000

                ScrollingText {
                    id: titleText

                    boundsBehavior: Flickable.StopAtBounds
                    text: c360program.coolDown ? "" : qsTr(viewObject.model.title(index)) + application.emptyString
                    onTextChanged: console.log("text>>",text)
                    color: "white"
                    font.bold: true
                    font.pixelSize: 40
                    anchors { horizontalCenter: parent.horizontalCenter; verticalCenter: parent.verticalCenter }
//                    wrapMode: Text.Wrap
//                    lineHeight: 0.7
                    width: 980
//                    elide: Text.ElideRight
                }
            }

            Image {
                id: photo
                anchors {
                    top: header.bottom ;
                    topMargin: 5 ;
                    left: parent.left ;
                    leftMargin: 20;
                    bottom: parent.bottom;
                    bottomMargin: 5

                }
                source: (c360Modes.imagePath() + images.get(0).source)

                fillMode: Image.PreserveAspectFit
                smooth: true

                MouseArea {
                    anchors.fill: parent

                    onClicked: { // for demonstration purposes, allow swithing phases by clicking photo: to be removed.
//                        viewObject.incrementCurrentIndex()
                    }
                }
            }

            Text {
                id: instText
                text: qsTr(viewObject.model.instructions(index)) + application.emptyString
                anchors { verticalCenter: photo.verticalCenter ; left: photo.right ; leftMargin: 0 }
            }

            Image {
                id: motionMan
                anchors {
                    top: header.bottom ;
                    topMargin: 5 ;
                    right: parent.right ;
                    leftMargin: 20 ;
                    bottom: parent.bottom;
                    bottomMargin: 5;

                }
                fillMode: Image.PreserveAspectFit
                smooth: true

                source: "graphics/c360/MotionMan/" + icon
            }

            Text {
                id: segTimeLabel
                anchors { bottom: parent.bottom ; bottomMargin: 50 ; left: photo.right ; leftMargin: 10 }
                text: qsTr("SEGMENT TIME REMAINING") + application.emptyString
                font.pointSize: 12
                font.bold: true
            }
            Text {
                id: segTimeIndicator
                anchors { left: segTimeLabel.right ; verticalCenter: segTimeLabel.verticalCenter }
                text: Format.formatTimeString(root.segmentTime)
                font.pointSize: 30
                font.bold: true
            }
        }
    }

    PathView {
        id: viewObject
        property int imageNum: 0

        preferredHighlightBegin: 0.5
        preferredHighlightEnd: 0.5
        pathItemCount: 2
        anchors.fill: parent
        interactive: false
        currentIndex: root.phase
        width: 1000
        height: 406

        model: c360Modes
        delegate: phaseImages
        clip: true
        path: Path {
            startX: viewObject.width *1.5
            startY: viewObject.height / 2
            PathLine {
                x: -viewObject.width /2
                y: viewObject.height / 2
            }
        }

        // timer to switch photo images between full and close-up
        Timer {
            id: imageTimer
            running: true
            repeat: true
            interval: 6000
            onTriggered: {
                viewObject.imageNum = (viewObject.imageNum ? 0 : 1)
            }
        }
    }
}
