import QtQuick 2.4
import Settings 1.0
import StorageMgr 1.0
import FileIO 1.0
import Components 1.0

Item {
    id: root

    property alias model: weblinks
    property string homepage: ""
    property string linksPath: "/data/weblinks"
    property string linksUSBPath: "/media/usb/weblinks"
    property variant extensions: ["*.url", "*.URL", "*.website"]

    signal linkSelected(string id)
    signal close()

    function loadLinks() {
        weblinks.clear()
        var linkfiles = linksStorage.listFiles(root.linksPath, extensions)
        for( var i=0 ; i < linkfiles.length ; i++) {
            linkfile.filename = root.linksPath + "/" + linkfiles[i]
            print("linkfile:" + linkfile.filename)
            var link = { id: linkfile.getValue("InternetShortcut/URL","nourl"),
                enabled: "true", number: i+1 , name: linkfiles[i].split(".")[0].slice(0,17) }
            if(linkfiles[i].split(".")[0] === "homepage")
                root.homepage = link.id
            print("link:" + link.id)
            weblinks.append(link)
        }
        print(weblinks.count + " Web links.")
        print("homepage:" + root.homepage)
    }

    function deleteCurrentLinks() {
        var filesToDelete = linksStorage.listFiles(root.linksPath, root.extensions)
        for (var i = 0; i < filesToDelete.length; i++) {
            var fullpath = root.linksPath + "/" + filesToDelete[i]
            var res = fileio.remove(fullpath)
            if (!res) {
                console.log("!! file remove failed", source)
            }
        }
    }

    function importLinks() {
        linksStorage.createDirectory(root.linksPath)

        deleteCurrentLinks()

        var linkfiles = linksStorage.listFiles(root.linksUSBPath, extensions)
        var count=0
        for (var i = 0; i < linkfiles.length; i++) {
            var source = root.linksUSBPath + "/" + linkfiles[i]
            var destination = root.linksPath + "/" + linkfiles[i]
            var res = fileio.copy(source, destination)
            if (!res) {
                console.log("!! file copy failed", source, destination)
                return 0
            }
            count++
        }
        return count
    }

    clip: true

    LayoutMirroring.enabled: Qt.application.layoutDirection === Qt.RightToLeft
    LayoutMirroring.childrenInherit: true

    ImageButton {
        id: close_button

        z: 200

        width: 48
        height: 48
        anchors {   right: parent.right ; rightMargin: 3 ;
                    top: parent.top ; topMargin: 3
        }
        upimage: "Keypad/KeyPad_X_Large.png"
        downimage: "Keypad/KeyPad_X_Large.png"

        onClicked: close()
        mouseAreaScale: 2.0
    }

    ChannelListView {
        anchors.fill: parent
        anchors.horizontalCenter: parent.horizontalCenter
        model: weblinks
        onChannelSelected: root.linkSelected(id)
    }

    Component.onCompleted: {
        loadLinks()
    }

    ListModel {
        id: weblinks
    }

    FileIO {
        id: fileio
    }

    StorageMgr {
        id: linksStorage
    }

    Settings {
        id: linkfile
    }
}
